Module node

Module node 

Traits for describing backend nodes and their observable properties.

Traits

LoadMetric
Exposes a load score for load-aware strategies. Lower is better.
Node
A backend node that can be selected by a load balancing strategy.
RateMetric
Exposes remaining capacity for quota-aware strategies. Higher is better.
Weighted
Exposes a weight for weighted strategies. Higher weight = more traffic.